==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/NbtSpawnPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllPackets;
import com.zurrtum.create.content.contraptions.data.ContraptionSyncLimiting;
import net.minecraft.class_1297;
import net.minecraft.class_2487;
import net.minecraft.class_2505;
import net.minecraft.class_2520;
import net.minecraft.class_2596;
import net.minecraft.class_2604;
import net.minecraft.class_3231;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.class_9145;
import org.jetbrains.annotations.Nullable;

public class NbtSpawnPacket extends class_2604 {
    public static final class_9139<class_9129, NbtSpawnPacket> field_47896 = class_2596.method_56443(NbtSpawnPacket::method_55855, NbtSpawnPacket::new);
    @Nullable
    private final class_2487 nbt;

    public NbtSpawnPacket(class_1297 entity, class_3231 entityTrackerEntry, class_2487 nbt) {
        super(entity, entityTrackerEntry);
        this.nbt = nbt;
    }

    private NbtSpawnPacket(class_9129 buf) {
        super(buf);
        class_2520 tag = buf.method_30616(class_2505.method_53898());
        if (tag != null && !(tag instanceof class_2487)) {
            nbt = null;
        } else {
            nbt = (class_2487) tag;
        }
    }

    @Override
    public void method_55855(class_9129 buf) {
        super.method_55855(buf);
        ContraptionSyncLimiting.writeSafe(nbt, buf);
    }

    @Nullable
    public class_2487 getNbt() {
        return nbt;
    }

    @Override
    @SuppressWarnings("unchecked")
    public class_9145<class_2604> method_65080() {
        return (class_9145<class_2604>) (class_9145<?>) AllPackets.NBT_SPAWN;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/NbtSpawnPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllPackets;
import com.zurrtum.create.content.contraptions.data.ContraptionSyncLimiting;
import net.minecraft.class_1297;
import net.minecraft.class_2487;
import net.minecraft.class_2505;
import net.minecraft.class_2520;
import net.minecraft.class_2596;
import net.minecraft.class_2604;
import net.minecraft.class_3231;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.class_9145;
import org.jetbrains.annotations.Nullable;

public class NbtSpawnPacket extends class_2604 {
    public static final class_9139<class_9129, NbtSpawnPacket> CODEC = class_2596.method_56443(NbtSpawnPacket::method_55855, NbtSpawnPacket::new);
    @Nullable
    private final class_2487 nbt;

    public NbtSpawnPacket(class_1297 entity, class_3231 entityTrackerEntry, class_2487 nbt) {
        super(entity, entityTrackerEntry);
        this.nbt = nbt;
    }

    private NbtSpawnPacket(class_9129 buf) {
        super(buf);
        class_2520 tag = buf.method_30616(class_2505.method_53898());
        if (tag != null && !(tag instanceof class_2487)) {
            nbt = null;
        } else {
            nbt = (class_2487) tag;
        }
    }

    @Override
    public void method_55855(class_9129 buf) {
        super.method_55855(buf);
        ContraptionSyncLimiting.writeSafe(nbt, buf);
    }

    @Nullable
    public class_2487 getNbt() {
        return nbt;
    }

    @Override
    @SuppressWarnings("unchecked")
    public class_9145<class_2604> method_65080() {
        return (class_9145<class_2604>) (class_9145<?>) AllPackets.NBT_SPAWN;
    }
}
